@@ -52,11 +52,19 @@ class Collection:
 
     @property
     def requires_owner(self):
+        return self.requires_owner_insert
+
+    @property
+    def requires_owner_insert(self):
         return (
             self.schema.__mro__[1] == SchemaWithOwner or
             self.schema.__mro__[1] == StaticSchemaWithOwner
         )
 
+    @property
+    def requires_owner_update(self):
+        return self.schema.__mro__[1] == SchemaWithOwner
+
     def get_unique_keys(self):
         return getattr(self.schema, '__unique_keys__', [])
 
@@ -255,7 +263,7 @@ class Collection:
             # Set updated date
             doc.updated_at = datetime.utcnow()
 
-        if self.requires_owner:
+        if self.requires_owner_update:
             if not force and (owner is None and self.force_ownership):
                 raise ValueError(f"An `owner` must be defined for collection {self.name}")
             doc.updated_by = owner
@@ -313,7 +321,7 @@ class Collection:
         if self.is_updatable:
             doc['updated_at'] = datetime.utcnow()
 
-        if self.requires_owner:
+        if self.requires_owner_update:
             if not force and (owner is None and self.force_ownership):
                 raise ValueError(f"An `owner` must be defined for collection {self.name}")
             doc['updated_by'] = owner
@@ -333,7 +341,7 @@ class Collection:
                     owner: Optional[str] = None,
                     force: Optional[bool] = False,
                     merge: Optional[bool] = False,
-                    batch_size: Optional[int] = 500) -> None:
+                    batch_size: Optional[int] = 300) -> None:
         if batch_size <= 0:
             raise ValueError('`batch_size` must be larger than 0')
         if len(docs) == 0:
@@ -386,7 +394,7 @@ class Collection:
         # Set created date
         doc.created_at = datetime.utcnow()
 
-        if self.requires_owner:
+        if self.requires_owner_insert:
             if not force and (owner is None and self.force_ownership):
                 raise ValueError(f"An `owner` must be defined for collection {self.name}")
             doc.created_by = owner
@@ -414,7 +422,7 @@ class Collection:
                     docs: List[Union[BaseModel, dict]],
                     owner: Optional[str] = None,
                     force: Optional[bool] = False,
-                    batch_size: Optional[int] = 500) -> None:
+                    batch_size: Optional[int] = 300) -> None:
         if batch_size <= 0:
             raise ValueError('`batch_size` must be larger than 0')
         if len(docs) == 0:
@@ -479,7 +487,7 @@ class Collection:
                     doc_ids: List[str],
                     owner: Optional[str] = None,
                     force: Optional[bool] = False,
-                    batch_size: Optional[int] = 500) -> None:
+                    batch_size: Optional[int] = 300) -> None:
         if batch_size <= 0:
             raise ValueError('`batch_size` must be larger than 0')
         if len(doc_ids) == 0:
@@ -497,6 +505,9 @@ class Collection:
         # Define batch operation
         write_batch = WriteBatch(client=self._client)
 
+        if update_before_delete:
+            batch_size = max(1, batch_size // 2)
+
         for i, doc_id in enumerate(doc_ids):
             if update_before_delete:
                 if self.is_updatable:
